# Introduction

While it shares a bit of a name with das uBoot, it's code is unrelated.  When `ipwndfu` was released it opened up the 
Apple built A5-11 processors to forever being able to run code.  But this was only the beginning.  `das iBoot` is
intended to pick up where `iwpndfu` leaves off.  By providing a framework to boot arbitrary code on an iDevice, it is
hoped that it will be used to launch `pongoOS`, "project sandcastle" and even non-signed iBoot payloads.

# Credits

* axi0miX for the `checkm8` bug

# License

Licensed under the LGPL-2.1